@@ -106,7 +106,7 @@ class LoadTradeKline(LoadData):
     def load(self, symbol, pbr, *args, **kwargs):
         unix_temp = self.unix_start
         previous_trade_id = None
-        for _ in range(1000):
+        for _ in range(10000):
             pbr.set_description(f'{symbol}-{unix_temp}')
             if unix_temp >= self.unix_end:
                 break
@@ -133,7 +133,7 @@ class LoadTradeKline(LoadData):
                 } for trade in trades]
 
                 self.write_data(result)
-                # time.sleep(int(self.exchange.rateLimit / 1000))
+                time.sleep(int(self.exchange.rateLimit / 1000))
             except ccxt.NetworkError as e:
                 print(type(e).__name__, str(e))
-                self.exchange.sleep(10000)
+                self.exchange.sleep(1000)
